/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.finance.entity;

import java.math.BigDecimal;
import com.baomidou.mybatisplus.annotation.TableName;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import java.time.LocalDateTime;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

/**
 * 用户提现表实体类
 *
 * @author BladeX
 * @since 2022-04-02
 */
@Data
@TableName("t_user_trade")
@ApiModel(value = "UserTrade对象", description = "用户提现表")
public class UserTrade implements Serializable {

	private static final long serialVersionUID = 1L;

	@TableId(value = "id", type = IdType.AUTO)
	private Long id;
	/**
	* 用户ID
	*/
		@ApiModelProperty(value = "用户ID")
		private Long userId;
	/**
	* 提现渠道，1，微信，2，支付（默认）
	*/
		@ApiModelProperty(value = "提现渠道，1，微信，2，支付（默认）")
		private Integer type;
	/**
	* 提现账号，支付宝账户、微信账户
	*/
		@ApiModelProperty(value = "提现账号，支付宝账户、微信账户")
		private String account;
	/**
	* 账户姓名
	*/
		@ApiModelProperty(value = "账户姓名")
		private String accountName;
	/**
	* 可提现金额（打款金额）
	*/
		@ApiModelProperty(value = "可提现金额（打款金额）")
		private BigDecimal money;
	/**
	* 提现来源，1，红包（默认），2：用户钱包，3：企业钱包，4，基金
	*/
		@ApiModelProperty(value = "提现来源，1，红包（默认），2：用户钱包，3：企业钱包，4，基金")
		private Integer cashFrom;
	/**
	* 有效状态，0：提现中，1：已到账，2：支付失败
	*/
		@ApiModelProperty(value = "有效状态，0：提现中，1：已到账，2：支付失败")
		private Integer status;
	/**
	* 创建时间
	*/
		@ApiModelProperty(value = "创建时间")
		private LocalDateTime createTime;
	/**
	* 支付成功时间
	*/
		@ApiModelProperty(value = "支付成功时间")
		private LocalDateTime updateTime;
	/**
	* 支付返回body
	*/
		@ApiModelProperty(value = "支付返回body")
		private String body;
	/**
	* 支付宝/微信用户Id
	*/
		@ApiModelProperty(value = "支付宝/微信用户Id")
		private String payId;
	/**
	* 支付宝/微信订单号
	*/
		@ApiModelProperty(value = "支付宝/微信订单号")
		private String outTradeNo;


}
