/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.shopping.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.shopping.entity.ConsignDist;
import org.springblade.modules.shopping.vo.ConsignDistVO;
import org.springblade.modules.shopping.wrapper.ConsignDistWrapper;
import org.springblade.modules.shopping.service.IConsignDistService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 配货表 控制器
 *
 * @author BladeX
 * @since 2022-03-15
 */
@RestController
@AllArgsConstructor
@RequestMapping("shopping/consigndist")
@Api(value = "配货表", tags = "配货表接口")
public class ConsignDistController extends BladeController {

	private final IConsignDistService consignDistService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入consignDist")
	public R<ConsignDistVO> detail(ConsignDist consignDist) {
		ConsignDist detail = consignDistService.getOne(Condition.getQueryWrapper(consignDist));
		return R.data(ConsignDistWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 配货表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入consignDist")
	public R<IPage<ConsignDistVO>> list(ConsignDist consignDist, Query query) {
		IPage<ConsignDist> pages = consignDistService.page(Condition.getPage(query), Condition.getQueryWrapper(consignDist));
		return R.data(ConsignDistWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 配货表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入consignDist")
	public R<IPage<ConsignDistVO>> page(ConsignDistVO consignDist, Query query) {
		IPage<ConsignDistVO> pages = consignDistService.selectConsignDistPage(Condition.getPage(query), consignDist);
		return R.data(pages);
	}

	/**
	 * 新增 配货表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入consignDist")
	public R save(@Valid @RequestBody ConsignDist consignDist) {
		return R.status(consignDistService.save(consignDist));
	}

	/**
	 * 修改 配货表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入consignDist")
	public R update(@Valid @RequestBody ConsignDist consignDist) {
		return R.status(consignDistService.updateById(consignDist));
	}

	/**
	 * 新增或修改 配货表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入consignDist")
	public R submit(@Valid @RequestBody ConsignDist consignDist) {
		return R.status(consignDistService.saveOrUpdate(consignDist));
	}

	
	/**
	 * 删除 配货表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(consignDistService.deleteLogic(Func.toLongList(ids)));
	}

	
}
