/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.shopping.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.shopping.entity.GoodsSearch;
import org.springblade.modules.shopping.vo.GoodsSearchVO;
import org.springblade.modules.shopping.wrapper.GoodsSearchWrapper;
import org.springblade.modules.shopping.service.IGoodsSearchService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 商品搜索表 控制器
 *
 * @author BladeX
 * @since 2022-03-15
 */
@RestController
@AllArgsConstructor
@RequestMapping("shopping/goodssearch")
@Api(value = "商品搜索表", tags = "商品搜索表接口")
public class GoodsSearchController extends BladeController {

	private final IGoodsSearchService goodsSearchService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入goodsSearch")
	public R<GoodsSearchVO> detail(GoodsSearch goodsSearch) {
		GoodsSearch detail = goodsSearchService.getOne(Condition.getQueryWrapper(goodsSearch));
		return R.data(GoodsSearchWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 商品搜索表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入goodsSearch")
	public R<IPage<GoodsSearchVO>> list(GoodsSearch goodsSearch, Query query) {
		IPage<GoodsSearch> pages = goodsSearchService.page(Condition.getPage(query), Condition.getQueryWrapper(goodsSearch));
		return R.data(GoodsSearchWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 商品搜索表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入goodsSearch")
	public R<IPage<GoodsSearchVO>> page(GoodsSearchVO goodsSearch, Query query) {
		IPage<GoodsSearchVO> pages = goodsSearchService.selectGoodsSearchPage(Condition.getPage(query), goodsSearch);
		return R.data(pages);
	}

	/**
	 * 新增 商品搜索表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入goodsSearch")
	public R save(@Valid @RequestBody GoodsSearch goodsSearch) {
		return R.status(goodsSearchService.save(goodsSearch));
	}

	/**
	 * 修改 商品搜索表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入goodsSearch")
	public R update(@Valid @RequestBody GoodsSearch goodsSearch) {
		return R.status(goodsSearchService.updateById(goodsSearch));
	}

	/**
	 * 新增或修改 商品搜索表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入goodsSearch")
	public R submit(@Valid @RequestBody GoodsSearch goodsSearch) {
		return R.status(goodsSearchService.saveOrUpdate(goodsSearch));
	}

	
	/**
	 * 删除 商品搜索表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(goodsSearchService.deleteLogic(Func.toLongList(ids)));
	}

	
}
